**-----------------------------------------------*
* Do file to run Volatility in Euro Area        *
* Pedro Gomes                                   *
* Abderrahim Taamouti					*
* Antonio Afonso                                *
* First Created February 2012                   *
* Updated  February 2012                        *
*---------------------------------------------- *


* Increase memory size
clear all
set mem 450m
set matsize 800
set more off
set logtype text

* Set working directory

cd "C:\STATACodes\"

*--------------------------------------------------*
* Section 1                                        *
* Extraction of main data (Euro Area+Europe)       * 
*                                                  *
*--------------------------------------------------*


insheet using "Data.txt", tab
save Data, replace

tsset time, daily

label var sp_equity "Equity index (Spain)"
label var de_equity "Equity index (Germany)"
label var fr_equity "Equity index (France)"
label var it_equity "Equity index (Italy)"

label var sp_yield "Bond yield(Spain)"
label var de_yield "Bond yield(Germany)"
label var fr_yield "Bond yield(France)"
label var it_yield "Bond yield(Italy)"


gen Monday=0
gen Tuesday=0
gen Wednesday=0
gen Thursday=0
gen Friday=0

replace Monday=1 if time2==15347
replace Tuesday=1 if time2==15341
replace Wednesday=1 if time2==15342
replace Thursday=1 if time2==15343
replace Friday=1 if time2==15344

replace Monday=1 if l5.Monday==1
replace Tuesday=1 if l5.Tuesday==1
replace Wednesday=1 if l5.Wednesday==1
replace Thursday=1 if l5.Thursday==1
replace Friday=1 if l5.Friday==1

gen AAA= Monday+ Tuesday+  Wednesday+ Thursday+ Friday 
sum AAA
drop AAA



gen Month = substr(date,4,3)
gen Year = substr(date,8,2)

gen jan=0
gen feb=0
gen mar=0
gen abr=0
gen may=0
gen jun=0
gen jul=0
gen aug=0
gen sep=0
gen oct=0
gen nov=0
gen dec=0

replace jan=1 if Month=="Jan"
replace feb=1 if Month=="Feb"
replace mar=1 if Month=="Mar"
replace abr=1 if Month=="Apr"
replace may=1 if Month=="May"
replace jun=1 if Month=="Jun"
replace jul=1 if Month=="Jul"
replace aug=1 if Month=="Aug"
replace sep=1 if Month=="Sep"
replace oct=1 if Month=="Oct"
replace nov=1 if Month=="Nov"
replace dec=1 if Month=="Dec"

gen AAA=  jan+ feb+  mar + abr + may+ jun+ jul+  aug + sep + oct+  nov+  dec 
sum AAA
drop AAA



destring Year, replace
replace Year=1900+Year if Year>50
replace Year=2000+Year if Year<50

gen Year02=0 
gen Year03=0 
gen Year04=0 
gen Year05=0 
gen Year06=0 
gen Year07=0 
gen Year08=0 
gen Year09=0 
gen Year10=0 
gen Year11=0 

replace Year02=1 if Year==2002
replace Year03=1 if Year==2003
replace Year04=1 if Year==2004
replace Year05=1 if Year==2005
replace Year06=1 if Year==2006
replace Year07=1 if Year==2007
replace Year08=1 if Year==2008
replace Year09=1 if Year==2009
replace Year10=1 if Year==2010
replace Year11=1 if Year==2011


gen WeekD=0

forvalues i = 1(1)878 { 
replace WeekD=`i' if time==5*(`i')-4
replace WeekD=`i' if time==5*(`i')-3
replace WeekD=`i' if time==5*(`i')-2
replace WeekD=`i' if time==5*(`i')-1
replace WeekD=`i' if time==5*(`i')
}

gen sp_S=log(sp_equity)-log(l.sp_equity)
gen de_S=log(de_equity)-log(l.de_equity)
gen fr_S=log(fr_equity)-log(l.fr_equity)
gen it_S=log(it_equity)-log(l.it_equity)

gen sp_Y=log(l.sp_yield/100)-log(sp_yield/100)
gen de_Y=log(l.de_yield/100)-log(de_yield/100)
gen fr_Y=log(l.fr_yield/100)-log(fr_yield/100)
gen it_Y=log(l.it_yield/100)-log(it_yield/100)


correl sp_S de_S fr_S it_S
correl sp_Y de_Y fr_Y it_Y

***********************************************************************************************
mgarch dcc (sp_S de_S=, arch(1/1) garch(1/1)), distribution(t) vce(robust)
predict V*, variance
gen C_de_S_sp_S=V_de_S_sp_S /( V_sp_S_sp_S^(0.5)* V_de_S_de_S^(0.5))
drop V_de_S_sp_S V_sp_S_sp_S V_de_S_de_S

mgarch dcc (sp_S it_S=, arch(1/1) garch(1/1)), distribution(t) vce(robust)
predict V*, variance
gen C_it_S_sp_S=V_it_S_sp_S /( V_sp_S_sp_S^(0.5)* V_it_S_it_S^(0.5))
drop V_it_S_sp_S V_sp_S_sp_S V_it_S_it_S

mgarch dcc (sp_S fr_S=, arch(1/1) garch(1/1)), distribution(t) vce(robust)
predict V*, variance
gen C_fr_S_sp_S=V_fr_S_sp_S /( V_sp_S_sp_S^(0.5)* V_fr_S_fr_S^(0.5))
drop V_fr_S_sp_S V_sp_S_sp_S V_fr_S_fr_S

mgarch dcc (de_S it_S=, arch(1/1) garch(1/1)), distribution(t) vce(robust)
predict V*, variance
gen C_it_S_de_S=V_it_S_de_S /( V_de_S_de_S^(0.5)* V_it_S_it_S^(0.5))
drop V_it_S_de_S V_de_S_de_S V_it_S_it_S

mgarch dcc (de_S fr_S=, arch(1/1) garch(1/1)), distribution(t) vce(robust)
predict V*, variance
gen C_fr_S_de_S=V_fr_S_de_S /( V_de_S_de_S^(0.5)* V_fr_S_fr_S^(0.5))
drop V_fr_S_de_S V_de_S_de_S V_fr_S_fr_S

mgarch dcc (it_S fr_S=, arch(1/1) garch(1/1)), distribution(t) vce(robust)
predict V*, variance
gen C_fr_S_it_S=V_fr_S_it_S /( V_it_S_it_S^(0.5)* V_fr_S_fr_S^(0.5))
drop V_fr_S_it_S V_it_S_it_S V_fr_S_fr_S

***********************************************************************************************
mgarch dcc (sp_Y de_Y=, arch(1/1) garch(1/1)), distribution(t) vce(robust)
predict V*, variance
gen C_de_Y_sp_Y=V_de_Y_sp_Y /( V_sp_Y_sp_Y^(0.5)* V_de_Y_de_Y^(0.5))
drop V_de_Y_sp_Y V_sp_Y_sp_Y V_de_Y_de_Y

mgarch dcc (sp_Y it_Y=, arch(1/1) garch(1/1)), distribution(t) vce(robust)
predict V*, variance
gen C_it_Y_sp_Y=V_it_Y_sp_Y /( V_sp_Y_sp_Y^(0.5)* V_it_Y_it_Y^(0.5))
drop V_it_Y_sp_Y V_sp_Y_sp_Y V_it_Y_it_Y

mgarch dcc (sp_Y fr_Y=, arch(1/1) garch(1/1)), distribution(t) vce(robust)
predict V*, variance
gen C_fr_Y_sp_Y=V_fr_Y_sp_Y /( V_sp_Y_sp_Y^(0.5)* V_fr_Y_fr_Y^(0.5))
drop V_fr_Y_sp_Y V_sp_Y_sp_Y V_fr_Y_fr_Y

mgarch dcc (de_Y it_Y=, arch(1/1) garch(1/1)), distribution(t) vce(robust)
predict V*, variance
gen C_it_Y_de_Y=V_it_Y_de_Y /( V_de_Y_de_Y^(0.5)* V_it_Y_it_Y^(0.5))
drop V_it_Y_de_Y V_de_Y_de_Y V_it_Y_it_Y

mgarch dcc (de_Y fr_Y=, arch(1/1) garch(1/1)), distribution(t) vce(robust)
predict V*, variance
gen C_fr_Y_de_Y=V_fr_Y_de_Y /( V_de_Y_de_Y^(0.5)* V_fr_Y_fr_Y^(0.5))
drop V_fr_Y_de_Y V_de_Y_de_Y V_fr_Y_fr_Y

mgarch dcc (it_Y fr_Y=, arch(1/1) garch(1/1)), distribution(t) vce(robust)
predict V*, variance
gen C_fr_Y_it_Y=V_fr_Y_it_Y /( V_it_Y_it_Y^(0.5)* V_fr_Y_fr_Y^(0.5))
drop V_fr_Y_it_Y V_it_Y_it_Y V_fr_Y_fr_Y


***********************************************************************************************
mgarch dcc (sp_Y sp_S=, arch(1/1) garch(1/1)), distribution(t) vce(robust)
predict V*, variance
gen C_sp_S_sp_Y=V_sp_S_sp_Y /( V_sp_Y_sp_Y^(0.5)* V_sp_S_sp_S^(0.5))
drop V_sp_S_sp_Y V_sp_Y_sp_Y V_sp_S_sp_S

mgarch dcc (de_Y de_S=, arch(1/1) garch(1/1)), distribution(t) vce(robust)
predict V*, variance
gen C_de_S_de_Y=V_de_S_de_Y /( V_de_Y_de_Y^(0.5)* V_de_S_de_S^(0.5))
drop V_de_S_de_Y V_de_Y_de_Y V_de_S_de_S

mgarch dcc (it_Y it_S=, arch(1/1) garch(1/1)), distribution(t) vce(robust)
predict V*, variance
gen C_it_S_it_Y=V_it_S_it_Y /( V_it_Y_it_Y^(0.5)* V_it_S_it_S^(0.5))
drop V_it_S_it_Y V_it_Y_it_Y V_it_S_it_S

mgarch dcc (fr_Y fr_S=, arch(1/1) garch(1/1)), distribution(t) vce(robust)
predict V*, variance
gen C_fr_S_fr_Y=V_fr_S_fr_Y /( V_fr_Y_fr_Y^(0.5)* V_fr_S_fr_S^(0.5))
drop V_fr_S_fr_Y V_fr_Y_fr_Y V_fr_S_fr_S

***********************************************************************************************
gen AC_de_S_sp_S =(C_de_S_sp_S + L.C_de_S_sp_S +L2.C_de_S_sp_S  +L3.C_de_S_sp_S +L4.C_de_S_sp_S )/5
gen AC_it_S_sp_S =(C_it_S_sp_S + L.C_it_S_sp_S +L2.C_it_S_sp_S  +L3.C_it_S_sp_S +L4.C_it_S_sp_S )/5
gen AC_fr_S_sp_S =(C_fr_S_sp_S + L.C_fr_S_sp_S +L2.C_fr_S_sp_S  +L3.C_fr_S_sp_S +L4.C_fr_S_sp_S )/5
gen AC_it_S_de_S =(C_it_S_de_S + L.C_it_S_de_S +L2.C_it_S_de_S  +L3.C_it_S_de_S +L4.C_it_S_de_S )/5
gen AC_fr_S_de_S =(C_fr_S_de_S+ L.C_fr_S_de_S +L2.C_fr_S_de_S  +L3.C_fr_S_de_S +L4.C_fr_S_de_S )/5
gen AC_fr_S_it_S =(C_fr_S_it_S  + L.C_fr_S_it_S  +L2.C_fr_S_it_S   +L3.C_fr_S_it_S  +L4.C_fr_S_it_S  )/5

gen AC_de_Y_sp_Y =(C_de_Y_sp_Y  + L.C_de_Y_sp_Y  +L2.C_de_Y_sp_Y   +L3.C_de_Y_sp_Y  +L4.C_de_Y_sp_Y  )/5
gen AC_it_Y_sp_Y =(C_it_Y_sp_Y  + L.C_it_Y_sp_Y  +L2.C_it_Y_sp_Y   +L3.C_it_Y_sp_Y  +L4.C_it_Y_sp_Y  )/5
gen AC_fr_Y_sp_Y =( C_fr_Y_sp_Y + L.C_fr_Y_sp_Y +L2.C_fr_Y_sp_Y  +L3.C_fr_Y_sp_Y +L4.C_fr_Y_sp_Y )/5
gen AC_it_Y_de_Y =(C_it_Y_de_Y  + L.C_it_Y_de_Y  +L2.C_it_Y_de_Y   +L3.C_it_Y_de_Y  +L4.C_it_Y_de_Y  )/5
gen AC_fr_Y_de_Y =(C_fr_Y_de_Y + L.C_fr_Y_de_Y +L2.C_fr_Y_de_Y  +L3.C_fr_Y_de_Y +L4.C_fr_Y_de_Y )/5
gen AC_fr_Y_it_Y =(C_fr_Y_it_Y  + L.C_fr_Y_it_Y  +L2.C_fr_Y_it_Y  +L3.C_fr_Y_it_Y  +L4.C_fr_Y_it_Y  )/5

gen AC_fr_S_fr_Y=( C_fr_S_fr_Y+ L.C_fr_S_fr_Y +L2.C_fr_S_fr_Y  +L3.C_fr_S_fr_Y +L4.C_fr_S_fr_Y )/5
gen AC_it_S_it_Y=( C_it_S_it_Y+ L.C_it_S_it_Y +L2.C_it_S_it_Y  +L3.C_it_S_it_Y +L4.C_it_S_it_Y )/5
gen AC_de_S_de_Y=( C_de_S_de_Y+ L.C_de_S_de_Y +L2.C_de_S_de_Y  +L3.C_de_S_de_Y +L4.C_de_S_de_Y )/5
gen AC_sp_S_sp_Y=( C_sp_S_sp_Y+ L.C_sp_S_sp_Y +L2.C_sp_S_sp_Y  +L3.C_sp_S_sp_Y +L4.C_sp_S_sp_Y )/5

drop C_de_S_sp_S C_it_S_sp_S  C_fr_S_sp_S C_it_S_de_S C_fr_S_de_S C_fr_S_it_S C_de_Y_sp_Y C_it_Y_sp_Y  C_fr_Y_sp_Y  C_it_Y_de_Y C_fr_Y_de_Y C_fr_Y_it_Y  C_fr_S_fr_Y  C_it_S_it_Y C_de_S_de_Y C_sp_S_sp_Y


gen AC20_de_S_sp_S =.
gen AC20_it_S_sp_S =.
gen AC20_fr_S_sp_S =.
gen AC20_it_S_de_S =.
gen AC20_fr_S_de_S =.
gen AC20_fr_S_it_S =.

gen AC20_de_Y_sp_Y =.
gen AC20_it_Y_sp_Y =.
gen AC20_fr_Y_sp_Y =.
gen AC20_it_Y_de_Y =.
gen AC20_fr_Y_de_Y =.
gen AC20_fr_Y_it_Y =.

gen AC20_fr_S_fr_Y=.
gen AC20_it_S_it_Y=.
gen AC20_de_S_de_Y=.
gen AC20_sp_S_sp_Y=.


forvalues i = 15368(1)18931{
display `i'
quietly  correl sp_S de_S   if time2<=`i' & time2>`i'-20 
quietly  replace AC20_de_S_sp_S  =r(rho) if time2==`i' 
quietly  correl  sp_S it_S  if time2<=`i' & time2>`i'-20 
quietly  replace AC20_it_S_sp_S=r(rho) if time2==`i' 
quietly  correl  sp_S fr_S  if time2<=`i' & time2>`i'-20 
quietly  replace AC20_fr_S_sp_S=r(rho) if time2==`i' 
quietly  correl  de_S it_S  if time2<=`i' & time2>`i'-20 
quietly  replace AC20_it_S_de_S=r(rho) if time2==`i' 
quietly  correl   de_S fr_S if time2<=`i' & time2>`i'-20 
quietly  replace AC20_fr_S_de_S=r(rho) if time2==`i' 
quietly  correl  it_S fr_S  if time2<=`i' & time2>`i'-20 
quietly  replace AC20_fr_S_it_S=r(rho) if time2==`i' 
quietly  correl   sp_Y de_Y if time2<=`i' & time2>`i'-20 
quietly  replace AC20_de_Y_sp_Y=r(rho) if time2==`i' 
quietly  correl   sp_Y it_Y if time2<=`i' & time2>`i'-20 
quietly  replace AC20_it_Y_sp_Y=r(rho) if time2==`i' 
quietly  correl   sp_Y fr_Y if time2<=`i' & time2>`i'-20 
quietly  replace  AC20_fr_Y_sp_Y=r(rho) if time2==`i' 
quietly  correl   de_Y it_Y if time2<=`i' & time2>`i'-20 
quietly  replace AC20_it_Y_de_Y=r(rho) if time2==`i' 
quietly  correl   de_Y fr_Y if time2<=`i' & time2>`i'-20 
quietly  replace AC20_fr_Y_de_Y=r(rho) if time2==`i' 
quietly  correl   it_Y fr_Y if time2<=`i' & time2>`i'-20 
quietly  replace AC20_fr_Y_it_Y=r(rho) if time2==`i' 
quietly  correl   sp_Y sp_S if time2<=`i' & time2>`i'-20 
quietly  replace AC20_sp_S_sp_Y=r(rho) if time2==`i' 
quietly  correl   de_Y de_S if time2<=`i' & time2>`i'-20 
quietly  replace AC20_de_S_de_Y=r(rho) if time2==`i' 
quietly  correl   it_Y it_S if time2<=`i' & time2>`i'-20 
quietly  replace AC20_it_S_it_Y=r(rho) if time2==`i' 
quietly  correl  fr_Y fr_S  if time2<=`i' & time2>`i'-20 
quietly  replace AC20_fr_S_fr_Y=r(rho) if time2==`i' 
}


gen Wsp_S=log(sp_equity)-log(l5.sp_equity)
gen Wde_S=log(de_equity)-log(l5.de_equity)
gen Wfr_S=log(fr_equity)-log(l5.fr_equity)
gen Wit_S=log(it_equity)-log(l5.it_equity)

gen Wsp_Y=log(l5.sp_yield/100)-log(sp_yield/100)
gen Wde_Y=log(l5.de_yield/100)-log(de_yield/100)
gen Wfr_Y=log(l5.fr_yield/100)-log(fr_yield/100)
gen Wit_Y=log(l5.it_yield/100)-log(it_yield/100)


label var   sp_S "Spain Stock Returns"
label var   de_S "Germany Stock Returns"
label var   fr_S "France Stock Returns"
label var   it_S "Italy Stock Returns"
label var   sp_Y "Spain Bond Returns"
label var   de_Y "Germany Bond Returns"
label var   fr_Y "France Bond Returns"
label var   it_Y "Italy Bond Returns"

label var   Wsp_S "Weekly Spain Stock Returns"
label var   Wde_S "Weekly Germany Stock Returns"
label var   Wfr_S "Weekly France Stock Returns"
label var   Wit_S "Weekly Italy Stock Returns"
label var   Wsp_Y "Weekly Spain Bond Returns"
label var   Wde_Y "Weekly Germany Bond Returns"
label var   Wfr_Y "Weekly France Bond Returns"
label var   Wit_Y "Weekly Italy Bond Returns"


label var  AC_de_S_sp_S "Alt. DCC Germany-Spain Stocks"
label var  AC_it_S_sp_S "Alt. DCC Italy-Spain Stocks"
label var  AC_fr_S_sp_S "Alt. DCC France-Spain Stocks"
label var  AC_it_S_de_S "Alt. DCC Italy-Germany Stocks"
label var  AC_fr_S_de_S "Alt. DCC France-Germany Stocks"
label var  AC_fr_S_it_S "Alt. DCC France-Spain Stocks"

label var  AC_de_Y_sp_Y "Alt. DCC Germany-Spain Bonds"
label var  AC_it_Y_sp_Y "Alt. DCC Italy-Spain Bonds"
label var  AC_fr_Y_sp_Y "Alt. DCC France-Spain Bonds"
label var  AC_it_Y_de_Y "Alt. DCC Italy-Germany Bonds"
label var  AC_fr_Y_de_Y "Alt. DCC France-Germany Bonds"
label var  AC_fr_Y_it_Y "Alt. DCC France-Spain Bonds"

label var  AC_fr_S_fr_Y "Alt. DCC France Stocks-Bonds"
label var  AC_it_S_it_Y "Alt. DCC Italy Stocks-Bonds"
label var  AC_de_S_de_Y "Alt. DCC Germany Stocks-Bonds"
label var  AC_sp_S_sp_Y "Alt. DCC Spain Stocks-Bonds"



label var  AC20_de_S_sp_S "20 days correlation: Germany-Spain Stocks"
label var  AC20_it_S_sp_S "20 days correlation:  Italy-Spain Stocks"
label var  AC20_fr_S_sp_S "20 days correlation:  France-Spain Stocks"
label var  AC20_it_S_de_S "20 days correlation:  Italy-Germany Stocks"
label var  AC20_fr_S_de_S "20 days correlation:  France-Germany Stocks"
label var  AC20_fr_S_it_S "20 days correlation:  France-Spain Stocks"

label var  AC20_de_Y_sp_Y "20 days correlation:  Germany-Spain Bonds"
label var  AC20_it_Y_sp_Y "20 days correlation:  Italy-Spain Bonds"
label var  AC20_fr_Y_sp_Y "20 days correlation:  France-Spain Bonds"
label var  AC20_it_Y_de_Y "20 days correlation:  Italy-Germany Bonds"
label var  AC20_fr_Y_de_Y "20 days correlation:  France-Germany Bonds"
label var  AC20_fr_Y_it_Y "20 days correlation:  France-Spain Bonds"

label var  AC20_fr_S_fr_Y "20 days correlation:  France Stocks-Bonds"
label var  AC20_it_S_it_Y "20 days correlation:  Italy Stocks-Bonds"
label var  AC20_de_S_de_Y "20 days correlation:  Germany Stocks-Bonds"
label var  AC20_sp_S_sp_Y "20 days correlation:  Spain Stocks-Bonds"

save data_daily, replace
saveold data_dailyold, replace

drop if  WeekD==f.WeekD
drop if time2==18931

gen WeekDD=WeekD+1818

tsset WeekDD, weekly

save data2, replace
saveold data2old, replace























