* Do file to run Volatility in Euro Area        *
* Pedro Gomes                                   *
* Abderrahim Taamouti					*
*  			                              *
* First Created February 2012                   *
* Updated  February 2012                        *
*---------------------------------------------- *


* Increase memory size
clear all
set mem 450m
set matsize 800
set more off
set logtype text

* Set working directory

cd "C:\STATACodes"

use  data5_logs.dta, clear


***********************************
***********************************
*Each country factor is highly correlated to the US factors. So do OLS regression of the country factors on the 2 Global factors and I save the residuals. These are the country specific factors that I'll include in the regression.
***********************************
***********************************
reg Lf1_de Lf1_us Lf2_us Lf3_us, vce(robust)
*predict xf1_de, residuals
reg Lf2_de Lf1_us Lf2_us Lf3_us, vce(robust) 
*predict xf2_de, residuals

reg Lf1_fr Lf1_us Lf2_us Lf3_us, vce(robust)
*predict xf1_fr, residuals
reg Lf2_fr Lf1_us Lf2_us Lf3_us 
*predict xf2_fr, residuals
reg Lf3_fr Lf1_us Lf2_us Lf3_us 
*predict xf3_fr, residuals

reg Lf1_it Lf1_us Lf2_us  Lf3_us
*predict xf1_it, residuals
reg Lf2_it Lf1_us Lf2_us  Lf3_us
*predict xf2_it, residuals
reg Lf3_it Lf1_us Lf2_us  Lf3_us
*predict xf3_it, residuals

reg Lf1_sp Lf1_us Lf2_us  Lf3_us
*predict xf1_sp, residuals
reg Lf2_sp Lf1_us Lf2_us  Lf3_us
*predict xf2_sp, residuals
reg Lf3_sp Lf1_us Lf2_us  Lf3_us
*predict xf3_sp, residuals



***********************************
***********************************
*Initial regressions: the Variances as a function of the 2 US factors. In general they are highly significant, particularly the first factor. They explain more of the bond correlation. The R2 vary between 0.10 to 0.50
***********************************
***********************************

***Stocks

*Germany
reg VAR_de_S  Lf1_us Lf2_us Lf3_us xf1_de xf2_de   , vce(robust)
estimates store DE_S

*France
reg VAR_fr_S Lf1_us Lf2_us Lf3_us  xf1_fr xf2_fr  xf3_fr , vce(robust)
estimates store FR_S

*Italy
reg VAR_it_S Lf1_us Lf2_us Lf3_us   xf1_it xf2_it  xf3_it, vce(robust)
estimates store IT_S

*Spain
reg VAR_sp_S  Lf1_us Lf2_us Lf3_us xf1_sp xf2_sp xf3_sp, vce(robust)
estimates store SP_S


estimates table DE_S FR_S IT_S SP_S, stats(N N_g r2) drop() b(%4.3f) t stfmt(%6.2g) style(oneline)
estimates table DE_S FR_S IT_S SP_S, stats(N N_g r2) star(.1 .05 .01) b(%4.3f) stfmt(%6.2g) style(oneline)



***Bonds


*Germany
reg VAR_de_Y  Lf1_us Lf2_us Lf3_us xf1_de xf2_de   , vce(robust)
estimates store DE_Y

*France
reg VAR_fr_Y Lf1_us Lf2_us Lf3_us  xf1_fr xf2_fr  xf3_fr , vce(robust)
estimates store FR_Y

*Italy
reg VAR_it_Y Lf1_us Lf2_us Lf3_us   xf1_it xf2_it  xf3_it, vce(robust)
estimates store IT_Y

*Spain
reg VAR_sp_Y  Lf1_us Lf2_us Lf3_us xf1_sp xf2_sp xf3_sp, vce(robust)
estimates store SP_Y


estimates table DE_Y FR_Y IT_Y SP_Y, stats(N N_g r2) drop() b(%4.3f) t stfmt(%6.2g) style(oneline)
estimates table DE_Y FR_Y IT_Y SP_Y, stats(N N_g r2) star(.1 .05 .01) b(%4.3f) stfmt(%6.2g) style(oneline)






***********************************
***********************************
*Initial regressions: the Variances as a function of the 2 US factors. In general they are highly significant, particularly the first factor. They explain more of the bond correlation. The R2 vary between 0.10 to 0.50
***********************************
***********************************
*With European Factors



reg Lf1_eu Lf1_us Lf2_us  Lf3_us
predict xf1_eu, residuals
reg Lf2_eu Lf1_us Lf2_us  Lf3_us
predict xf2_eu, residuals
reg Lf3_eu Lf1_us Lf2_us  Lf3_us
predict xf3_eu, residuals

***Stocks

reg COV_fr_S_de_S Lf1_us Lf2_us Lf3_us  , vce(robust)
estimates store DE_FR1
reg COV_fr_S_de_S Lf1_us Lf2_us Lf3_us xf1_eu xf2_eu  xf3_eu , vce(robust)
estimates store DE_FR2

reg COV_it_S_de_S Lf1_us Lf2_us Lf3_us , vce(robust)
estimates store DE_IT1
reg COV_it_S_de_S Lf1_us Lf2_us Lf3_us xf1_eu xf2_eu  xf3_eu , vce(robust)
estimates store DE_IT2

reg COV_de_S_sp_S  Lf1_us Lf2_us Lf3_us , vce(robust)
estimates store DE_SP1
reg COV_de_S_sp_S  Lf1_us Lf2_us Lf3_us xf1_eu xf2_eu  xf3_eu  , vce(robust)
estimates store DE_SP2

reg COV_fr_S_it_S  Lf1_us Lf2_us Lf3_us  , vce(robust)
estimates store FR_IT1
reg COV_fr_S_it_S  Lf1_us Lf2_us Lf3_us xf1_eu xf2_eu  xf3_eu , vce(robust)
estimates store FR_IT2

reg COV_fr_S_sp_S  Lf1_us Lf2_us Lf3_us , vce(robust)
estimates store FR_SP1 
reg COV_fr_S_sp_S  Lf1_us Lf2_us Lf3_us xf1_eu xf2_eu  xf3_eu , vce(robust)
estimates store FR_SP2

reg COV_it_S_sp_S  Lf1_us Lf2_us Lf3_us , vce(robust)
estimates store IT_SP1
reg COV_it_S_sp_S  Lf1_us Lf2_us Lf3_us xf1_eu xf2_eu  xf3_eu , vce(robust)
estimates store IT_SP2


estimates table DE_FR1 DE_FR2 DE_IT1 DE_IT2 DE_SP1 DE_SP2 FR_IT1 FR_IT2 FR_SP1 FR_SP2 IT_SP1 IT_SP2, stats(N N_g r2) drop() b(%4.3f) t stfmt(%6.2g) style(oneline)
estimates table DE_FR1 DE_FR2 DE_IT1 DE_IT2 DE_SP1 DE_SP2 FR_IT1 FR_IT2 FR_SP1 FR_SP2 IT_SP1 IT_SP2, stats(N N_g r2) star(.1 .05 .01) b(%4.3f) stfmt(%6.2g) style(oneline)



***Bonds

reg COV_fr_Y_de_Y Lf1_us Lf2_us Lf3_us , vce(robust)
estimates store DE_FR1
reg COV_fr_Y_de_Y Lf1_us Lf2_us Lf3_us xf1_eu xf2_eu  xf3_eu , vce(robust)
estimates store DE_FR2

reg COV_it_Y_de_Y Lf1_us Lf2_us Lf3_us  , vce(robust)
estimates store DE_IT1
reg COV_it_Y_de_Y Lf1_us Lf2_us Lf3_us xf1_eu xf2_eu  xf3_eu , vce(robust)
estimates store DE_IT2

reg COV_de_Y_sp_Y Lf1_us Lf2_us Lf3_us , vce(robust)
estimates store DE_SP1
reg COV_de_Y_sp_Y Lf1_us Lf2_us Lf3_us xf1_eu xf2_eu  xf3_eu  , vce(robust)
estimates store DE_SP2

reg COV_fr_Y_it_Y Lf1_us Lf2_us Lf3_us  , vce(robust)
estimates store FR_IT1
reg C_fr_Y_it_Y Lf1_us Lf2_us Lf3_us xf1_eu xf2_eu  xf3_eu  , vce(robust)
estimates store FR_IT2

reg COV_fr_Y_sp_Y Lf1_us Lf2_us Lf3_us , vce(robust)
estimates store FR_SP1 
reg COV_fr_Y_sp_Y Lf1_us Lf2_us Lf3_us xf1_eu xf2_eu  xf3_eu  , vce(robust)
estimates store FR_SP2

reg COV_it_Y_sp_Y Lf1_us Lf2_us Lf3_us , vce(robust)
estimates store IT_SP1
reg COV_it_Y_sp_Y Lf1_us Lf2_us Lf3_us xf1_eu xf2_eu  xf3_eu  , vce(robust)
estimates store IT_SP2


estimates table DE_FR1 DE_FR2 DE_IT1 DE_IT2 DE_SP1 DE_SP2 FR_IT1 FR_IT2 FR_SP1 FR_SP2 IT_SP1 IT_SP2, stats(N N_g r2) drop() b(%4.3f) t stfmt(%6.2g) style(oneline)
estimates table DE_FR1 DE_FR2 DE_IT1 DE_IT2 DE_SP1 DE_SP2 FR_IT1 FR_IT2 FR_SP1 FR_SP2 IT_SP1 IT_SP2, stats(N N_g r2) star(.1 .05 .01) b(%4.3f) stfmt(%6.2g) style(oneline)



